# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/stream_audio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/stream_audio.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n5cogneed-protos/cogneed-ks/services/stream_audio.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\".\n\x0bModelConfig\x12\x10\n\x08use_case\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\"g\n\tAudioInfo\x12\x35\n\x05\x63odec\x18\x01 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.AudioCodec\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x03\x12\x0e\n\x06stereo\x18\x03 \x01(\x08\"#\n\x11PersistenceConfig\x12\x0e\n\x06record\x18\x01 \x01(\x08\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\xd3\x01\n\x12InitSessionRequest\x12\x37\n\tuser_info\x18\x01 \x01(\x0b\x32$.ai.cogneed.cloud.speech.v1.UserInfo\x12\x39\n\naudio_info\x18\x02 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioInfo\x12I\n\x12persistence_config\x18\x03 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.PersistenceConfig\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x97\x01\n\x12\x41udioDetectRequest\x12>\n\x04init\x18\x01 \x01(\x0b\x32..ai.cogneed.cloud.speech.v1.InitSessionRequestH\x00\x12\x36\n\x05\x61udio\x18\x02 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioBlobH\x00\x42\t\n\x07request\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"e\n\x13InitSessionResponse\x12;\n\x0bstatus_code\x18\x01 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.StatusCode\x12\x11\n\tcall_uuid\x18\x02 \x01(\t\"M\n\x0eStatusResponse\x12;\n\x0bstatus_code\x18\x01 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.StatusCode\")\n\x11\x45ndSessionRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"(\n\x10SubscribeRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"\x9e\x01\n\x14SubscriptionResponse\x12\x42\n\tdetection\x18\x01 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.DetectionResponseH\x00\x12\x36\n\x04\x62\x65\x61t\x18\x02 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.StatusCodeH\x00\x42\n\n\x08response\"]\n\x0fWebAudioRequest\x12\x34\n\x05\x61udio\x18\x01 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioBlob\x12\x14\n\x0csession_uuid\x18\x02 \x01(\t*C\n\nStatusCode\x12\x06\n\x02OK\x10\x00\x12\x10\n\x0cSERVER_ERROR\x10\x01\x12\x1b\n\x17SESSION_DOES_NOT_EXISTS\x10\x02*\x1f\n\nAudioCodec\x12\x07\n\x03WAV\x10\x00\x12\x08\n\x04OPUS\x10\x01\x32\x87\x01\n\x12StreamAudioService\x12q\n\x0cstream_audio\x12..ai.cogneed.cloud.speech.v1.AudioDetectRequest\x1a-.ai.cogneed.cloud.speech.v1.DetectionResponse(\x01\x30\x01\x32\xbd\x03\n\x0fWebAudioService\x12o\n\x0cinit_session\x12..ai.cogneed.cloud.speech.v1.InitSessionRequest\x1a/.ai.cogneed.cloud.speech.v1.InitSessionResponse\x12`\n\x05\x61udio\x12+.ai.cogneed.cloud.speech.v1.WebAudioRequest\x1a*.ai.cogneed.cloud.speech.v1.StatusResponse\x12h\n\x0b\x65nd_session\x12-.ai.cogneed.cloud.speech.v1.EndSessionRequest\x1a*.ai.cogneed.cloud.speech.v1.StatusResponse\x12m\n\tsubscribe\x12,.ai.cogneed.cloud.speech.v1.SubscribeRequest\x1a\x30.ai.cogneed.cloud.speech.v1.SubscriptionResponse0\x01\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='ai.cogneed.cloud.speech.v1.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_DOES_NOT_EXISTS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1297,
  serialized_end=1364,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.cloud.speech.v1.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WAV', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPUS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1366,
  serialized_end=1397,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
OK = 0
SERVER_ERROR = 1
SESSION_DOES_NOT_EXISTS = 2
WAV = 0
OPUS = 1



_MODELCONFIG = _descriptor.Descriptor(
  name='ModelConfig',
  full_name='ai.cogneed.cloud.speech.v1.ModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.cloud.speech.v1.ModelConfig.use_case', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.cloud.speech.v1.ModelConfig.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=131,
)


_AUDIOINFO = _descriptor.Descriptor(
  name='AudioInfo',
  full_name='ai.cogneed.cloud.speech.v1.AudioInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.codec', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.sample_rate', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stereo', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.stereo', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=236,
)


_PERSISTENCECONFIG = _descriptor.Descriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.cloud.speech.v1.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.cloud.speech.v1.PersistenceConfig.record', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=273,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.cloud.speech.v1.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.cloud.speech.v1.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.cloud.speech.v1.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=315,
)


_INITSESSIONREQUEST = _descriptor.Descriptor(
  name='InitSessionRequest',
  full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.audio_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.persistence_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=529,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.cloud.speech.v1.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=559,
)


_AUDIODETECTREQUEST = _descriptor.Descriptor(
  name='AudioDetectRequest',
  full_name='ai.cogneed.cloud.speech.v1.AudioDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='init', full_name='ai.cogneed.cloud.speech.v1.AudioDetectRequest.init', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.cloud.speech.v1.AudioDetectRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='ai.cogneed.cloud.speech.v1.AudioDetectRequest.request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=562,
  serialized_end=713,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.cloud.speech.v1.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.cloud.speech.v1.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.cloud.speech.v1.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=772,
)


_INITSESSIONRESPONSE = _descriptor.Descriptor(
  name='InitSessionResponse',
  full_name='ai.cogneed.cloud.speech.v1.InitSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='ai.cogneed.cloud.speech.v1.InitSessionResponse.status_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.cloud.speech.v1.InitSessionResponse.call_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=875,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='ai.cogneed.cloud.speech.v1.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='ai.cogneed.cloud.speech.v1.StatusResponse.status_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=954,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.cloud.speech.v1.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.cloud.speech.v1.EndSessionRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=997,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='ai.cogneed.cloud.speech.v1.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.cloud.speech.v1.SubscribeRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1039,
)


_SUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='SubscriptionResponse',
  full_name='ai.cogneed.cloud.speech.v1.SubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='ai.cogneed.cloud.speech.v1.SubscriptionResponse.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beat', full_name='ai.cogneed.cloud.speech.v1.SubscriptionResponse.beat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='ai.cogneed.cloud.speech.v1.SubscriptionResponse.response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1042,
  serialized_end=1200,
)


_WEBAUDIOREQUEST = _descriptor.Descriptor(
  name='WebAudioRequest',
  full_name='ai.cogneed.cloud.speech.v1.WebAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.cloud.speech.v1.WebAudioRequest.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.cloud.speech.v1.WebAudioRequest.session_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1295,
)

_AUDIOINFO.fields_by_name['codec'].enum_type = _AUDIOCODEC
_INITSESSIONREQUEST.fields_by_name['user_info'].message_type = _USERINFO
_INITSESSIONREQUEST.fields_by_name['audio_info'].message_type = _AUDIOINFO
_INITSESSIONREQUEST.fields_by_name['persistence_config'].message_type = _PERSISTENCECONFIG
_AUDIODETECTREQUEST.fields_by_name['init'].message_type = _INITSESSIONREQUEST
_AUDIODETECTREQUEST.fields_by_name['audio'].message_type = _AUDIOBLOB
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['init'])
_AUDIODETECTREQUEST.fields_by_name['init'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['audio'])
_AUDIODETECTREQUEST.fields_by_name['audio'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
_INITSESSIONRESPONSE.fields_by_name['status_code'].enum_type = _STATUSCODE
_STATUSRESPONSE.fields_by_name['status_code'].enum_type = _STATUSCODE
_SUBSCRIPTIONRESPONSE.fields_by_name['detection'].message_type = _DETECTIONRESPONSE
_SUBSCRIPTIONRESPONSE.fields_by_name['beat'].enum_type = _STATUSCODE
_SUBSCRIPTIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SUBSCRIPTIONRESPONSE.fields_by_name['detection'])
_SUBSCRIPTIONRESPONSE.fields_by_name['detection'].containing_oneof = _SUBSCRIPTIONRESPONSE.oneofs_by_name['response']
_SUBSCRIPTIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SUBSCRIPTIONRESPONSE.fields_by_name['beat'])
_SUBSCRIPTIONRESPONSE.fields_by_name['beat'].containing_oneof = _SUBSCRIPTIONRESPONSE.oneofs_by_name['response']
_WEBAUDIOREQUEST.fields_by_name['audio'].message_type = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['ModelConfig'] = _MODELCONFIG
DESCRIPTOR.message_types_by_name['AudioInfo'] = _AUDIOINFO
DESCRIPTOR.message_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['InitSessionRequest'] = _INITSESSIONREQUEST
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['AudioDetectRequest'] = _AUDIODETECTREQUEST
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['InitSessionResponse'] = _INITSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['SubscriptionResponse'] = _SUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name['WebAudioRequest'] = _WEBAUDIOREQUEST
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModelConfig = _reflection.GeneratedProtocolMessageType('ModelConfig', (_message.Message,), dict(
  DESCRIPTOR = _MODELCONFIG,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ModelConfig)
  ))
_sym_db.RegisterMessage(ModelConfig)

AudioInfo = _reflection.GeneratedProtocolMessageType('AudioInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOINFO,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioInfo)
  ))
_sym_db.RegisterMessage(AudioInfo)

PersistenceConfig = _reflection.GeneratedProtocolMessageType('PersistenceConfig', (_message.Message,), dict(
  DESCRIPTOR = _PERSISTENCECONFIG,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.PersistenceConfig)
  ))
_sym_db.RegisterMessage(PersistenceConfig)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)

InitSessionRequest = _reflection.GeneratedProtocolMessageType('InitSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitSessionRequest)
  ))
_sym_db.RegisterMessage(InitSessionRequest)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

AudioDetectRequest = _reflection.GeneratedProtocolMessageType('AudioDetectRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIODETECTREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioDetectRequest)
  ))
_sym_db.RegisterMessage(AudioDetectRequest)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)

InitSessionResponse = _reflection.GeneratedProtocolMessageType('InitSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitSessionResponse)
  ))
_sym_db.RegisterMessage(InitSessionResponse)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.SubscribeRequest)
  ))
_sym_db.RegisterMessage(SubscribeRequest)

SubscriptionResponse = _reflection.GeneratedProtocolMessageType('SubscriptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONRESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.SubscriptionResponse)
  ))
_sym_db.RegisterMessage(SubscriptionResponse)

WebAudioRequest = _reflection.GeneratedProtocolMessageType('WebAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _WEBAUDIOREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.stream_audio_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.WebAudioRequest)
  ))
_sym_db.RegisterMessage(WebAudioRequest)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.cloud.speech.v1.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1400,
  serialized_end=1535,
  methods=[
  _descriptor.MethodDescriptor(
    name='stream_audio',
    full_name='ai.cogneed.cloud.speech.v1.StreamAudioService.stream_audio',
    index=0,
    containing_service=None,
    input_type=_AUDIODETECTREQUEST,
    output_type=_DETECTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE


_WEBAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='WebAudioService',
  full_name='ai.cogneed.cloud.speech.v1.WebAudioService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=1538,
  serialized_end=1983,
  methods=[
  _descriptor.MethodDescriptor(
    name='init_session',
    full_name='ai.cogneed.cloud.speech.v1.WebAudioService.init_session',
    index=0,
    containing_service=None,
    input_type=_INITSESSIONREQUEST,
    output_type=_INITSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='audio',
    full_name='ai.cogneed.cloud.speech.v1.WebAudioService.audio',
    index=1,
    containing_service=None,
    input_type=_WEBAUDIOREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='end_session',
    full_name='ai.cogneed.cloud.speech.v1.WebAudioService.end_session',
    index=2,
    containing_service=None,
    input_type=_ENDSESSIONREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='subscribe',
    full_name='ai.cogneed.cloud.speech.v1.WebAudioService.subscribe',
    index=3,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=_SUBSCRIPTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBAUDIOSERVICE)

DESCRIPTOR.services_by_name['WebAudioService'] = _WEBAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
